package com.ruoyi.yh.logImport.service;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.yh.logImport.domain.LogImport;
import com.ruoyi.yh.logImport.domain.LogImportQuery;
import com.ruoyi.yh.logImport.domain.LogImportVO;
import com.ruoyi.yh.logImport.domain.enums.LogImportBizType;
import com.ruoyi.yh.logImport.domain.enums.LogImportType;

import java.util.List;

/**
 * 导入日志Service接口
 *
 * @author ruoyi
 * @date 2024-11-07
 */
public interface LogImportService
{
    /**
     * 查询导入日志
     *
     * @param logId 导入日志主键
     * @return 导入日志
     */
    public LogImportVO selectLogImportByLogId(Long logId);

    /**
     * 查询导入日志列表
     *
     * @param logImport 导入日志
     * @return 导入日志集合
     */
    public List<LogImportVO> selectLogImportList(LogImportQuery logImport);

    /**
     * 新增导入日志
     *
     * @param logImport 导入日志
     * @return 结果
     */
    public int insertLogImport(LogImport logImport);

    /**
     * 修改导入日志
     *
     * @param logImport 导入日志
     * @return 结果
     */
    public int updateLogImport(LogImport logImport);

    /**
     * 批量删除导入日志
     *
     * @param logIds 需要删除的导入日志主键集合
     * @return 结果
     */
    public int deleteLogImportByLogIds(Long[] logIds);

    /**
     * 删除导入日志信息
     *
     * @param logId 导入日志主键
     * @return 结果
     */
    public int deleteLogImportByLogId(Long logId);

    /**
     * 新增一个默认日志
     *
     * @param type
     * @param bizType
     * @param user
     */
    LogImportVO addDefaultLog(LogImportType type, LogImportBizType bizType, SysUser user);

    /**
     * 创建一个默认日志
     */
    LogImportVO addDefaultLog(LogImportType type, LogImportBizType bizType, Long operaId);

    /**
     * 更新结果为已完成
     */
    int updateLogToFinished(Long logId);

}
