package com.ruoyi.yh.logImport.service.impl;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.yh.logImport.domain.LogImport;
import com.ruoyi.yh.logImport.domain.LogImportQuery;
import com.ruoyi.yh.logImport.domain.LogImportVO;
import com.ruoyi.yh.logImport.domain.enums.LogImportBizType;
import com.ruoyi.yh.logImport.domain.enums.LogImportStatus;
import com.ruoyi.yh.logImport.domain.enums.LogImportType;
import com.ruoyi.yh.logImport.mapper.LogImportMapper;
import com.ruoyi.yh.logImport.service.LogImportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 导入日志Service业务层处理
 *
 * @author ruoyi
 * @date 2024-11-07
 */
@Service
public class LogImportServiceImpl implements LogImportService
{
    @Autowired
    private LogImportMapper logImportMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private ISysUserService userService;

    /**
     * 查询导入日志
     *
     * @param logId 导入日志主键
     * @return 导入日志
     */
    @Override
    public LogImportVO selectLogImportByLogId(Long logId)
    {
        return logImportMapper.selectLogImportByLogId(logId);
    }

    /**
     * 查询导入日志列表
     *
     * @param logImport 导入日志
     * @return 导入日志
     */
    @Override
    public List<LogImportVO> selectLogImportList(LogImportQuery logImport)
    {
        return logImportMapper.selectLogImportList(logImport);
    }

    /**
     * 新增导入日志
     *
     * @param logImport 导入日志
     * @return 结果
     */
    @Override
    public int insertLogImport(LogImport logImport)
    {
        logImport.setCreateTime(DateUtils.getNowDate());
        return logImportMapper.insertLogImport(logImport);
    }

    /**
     * 修改导入日志
     *
     * @param logImport 导入日志
     * @return 结果
     */
    @Override
    public int updateLogImport(LogImport logImport)
    {
        return logImportMapper.updateLogImport(logImport);
    }

    /**
     * 批量删除导入日志
     *
     * @param logIds 需要删除的导入日志主键
     * @return 结果
     */
    @Override
    public int deleteLogImportByLogIds(Long[] logIds)
    {
        return logImportMapper.deleteLogImportByLogIds(logIds);
    }

    /**
     * 删除导入日志信息
     *
     * @param logId 导入日志主键
     * @return 结果
     */
    @Override
    public int deleteLogImportByLogId(Long logId)
    {
        return logImportMapper.deleteLogImportByLogId(logId);
    }

    @Override
    public LogImportVO addDefaultLog(LogImportType type, LogImportBizType bizType, SysUser user) {
        LogImport po = new LogImport();
        po.setStatus(LogImportStatus.PROCESSING.getStatus());
        po.setBizType(bizType.getType());
        po.setCreateId(user.getUserId());
        po.setCreateBy(user.getNickName());
        po.setType(type.getType());

        int insert = this.insertLogImport(po);
        ServiceUtil.assertion(insert != 1, "新增导入日志失败");

        return selectLogImportByLogId(po.getLogId());
    }

    @Override
    public LogImportVO addDefaultLog(LogImportType type, LogImportBizType bizType, Long operaId) {
        // 操作人
        SysUser user = null;
        if (Constants.SYSTEM_USER_ID.equals(operaId)) {
            user = SysUser.system();
        } else {
            user = userService.selectUserById(operaId);
        }

        return this.addDefaultLog(type, bizType, user);
    }

    @Override
    public int updateLogToFinished(Long logId) {
        if (logId == null) {
            return 0;
        }

        LogImport data = new LogImport();
        data.setLogId(logId);
        data.setStatus(LogImportStatus.FINISHED.getStatus());
        data.setFinishedTime(LocalDateTime.now());
        return logImportMapper.updateLogImport(data);
    }
}
