package com.ruoyi.yh.material.service.impl;

import com.alibaba.fastjson2.JSONArray;
import com.ruoyi.common.k3cloud.constants.fileds.K3MaterialField;
import com.ruoyi.yh.material.domain.Material;
import com.ruoyi.yh.material.domain.vo.MaterialNumberSplitVO;
import com.ruoyi.yh.material.service.MaterialConverter;
import com.ruoyi.yh.material.utils.MaterialUtil;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author wjh
 * 2024/11/12
 */
@Service
public class MaterialConverterImpl implements MaterialConverter {
    @Override
    public List<Material> toPoByErpList(List<String> headers, List<JSONArray> erpList) {

        if (CollectionUtils.isEmpty(headers) || CollectionUtils.isEmpty(erpList)) {
            return Collections.emptyList();
        }

        // 创建erpList大小的对象列表
        List<Material> result = new ArrayList<>(erpList.size());

        for (JSONArray row : erpList) {
            Material po = new Material();
            for (int i = 0; i < headers.size(); i++) {
                String header = headers.get(i);
                switch (header) {
                    case K3MaterialField.F_MATERIAL_ID:
                        po.setErpId(row.getString(i));
                        break;
                    case K3MaterialField.F_NAME:
                        po.setErpName(row.getString(i));
                        break;
                    case K3MaterialField.F_NUMBER:
                        po.setErpNumber(row.getString(i));
                        break;
                    case K3MaterialField.F_SPECIFICATION:
                        po.setErpSpec(row.getString(i));
                        break;
                    default:
                        break;
                }
            }
            // 处理物料编码
            MaterialNumberSplitVO vo = MaterialUtil.parseToSplit(po.getErpNumber());
            if (vo != null) {
                po.setWorkShops(vo.getWorkShops());
                po.setCategory(vo.getCategory());
                po.setSize(vo.getSize());
                po.setSurface(vo.getSurface());
                po.setCover(vo.getCover());
                po.setGraphics(vo.getGraphics());
            }

            result.add(po);
        }

        return result;
    }
}
