package com.ruoyi.yh.material.utils;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.yh.material.domain.vo.MaterialNumberSplitVO;
import lombok.extern.slf4j.Slf4j;

import java.util.Arrays;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 物料工具类
 * @author wjh
 * 2024/11/15
 */
@Slf4j
public class MaterialUtil {

    /**
     * 将物料编码拆分成各个部分
     */
    public static MaterialNumberSplitVO parseToSplit(String materialNumber) {
        if (StringUtils.isBlank(materialNumber)) {
            return null;
        }
        MaterialNumberSplitVO vo = new MaterialNumberSplitVO();

        // 拆分出前后两部分
        String[] numberPattern = materialNumber.split("/");

        // 处理前部分
        if (numberPattern.length > 0) {
            // 根据点进行拆分
            String regex = "\\.";
            String[] split = numberPattern[0].split(regex);

            // 生产车间
            if (split.length > 2) {
                String workShopIds = split[2];
                vo.setWorkShops(Arrays.asList(workShopIds.split("-")));
            }
            if (split.length > 3) {
                vo.setCategory(split[3]);
            }
            if (split.length > 4) {
                String sizeString = split[4];
                try {
                    vo.setSize(String.valueOf(Integer.parseInt(sizeString)));
                } catch (Exception e) {
                    vo.setSize(sizeString);
                    log.error("sizeString 转换异常", e);
                }
            }
            if (split.length > 5) {
                vo.setSurface(split[5]);
            }
            if (split.length > 6) {
                vo.setGraphics(split[6]);
            }
        }

        // 处理后部分
        if (numberPattern.length > 1) {
            // 处理盖子
            vo.setCover(numberPattern[1]);
        }

        return vo;
    }

    public static String parseToCode(String category, String size, String surface, String graphics) {
        // 除了盖子，其余都用点连接，如果为空或者空字符串，则忽略
        String code = Stream.of(category, size, surface, graphics)
                .filter(StringUtils::isNotBlank)
                .collect(Collectors.joining("."));

        return code;
    }
}
