package com.ruoyi.yh.price.service;

import com.ruoyi.yh.price.domain.Price;
import com.ruoyi.yh.price.domain.PriceQuery;
import com.ruoyi.yh.price.domain.PriceVO;
import com.ruoyi.yh.price.domain.dto.PriceImportParams;
import com.ruoyi.yh.price.domain.dto.PriceVerifyDTO;
import com.ruoyi.yh.price.domain.vo.PriceSearchConditionVO;

import java.util.List;

/**
 * 单价Service接口
 *
 * @author ruoyi
 * @date 2024-10-17
 */
public interface PriceService
{
    /**
     * 查询单价
     *
     * @param priceId 单价主键
     * @return 单价
     */
    public PriceVO selectPriceByPriceId(Long priceId);

    /**
     * 查询单价列表
     *
     * @param price 单价
     * @return 单价集合
     */
    public List<PriceVO> selectPriceList(PriceQuery price);

    /**
     * 新增单价
     *
     * @param price 单价
     * @return 结果
     */
    public int insertPrice(Price price);

    /**
     * 修改单价
     *
     * @param price 单价
     * @return 结果
     */
    public int updatePrice(Price price);

    /**
     * 批量删除单价
     *
     * @param priceIds 需要删除的单价主键集合
     * @return 结果
     */
    public int deletePriceByPriceIds(Long[] priceIds);

    /**
     * 删除单价信息
     *
     * @param priceId 单价主键
     * @return 结果
     */
    public int deletePriceByPriceId(Long priceId);

    /**
     * 条件更新
     * @param data 数据
     * @param query 条件
     */
    int updateByQuery(Price data, PriceQuery query);

    /**
     * 提交审核
     * @param priceId 单价ID
     */
    int submit(Long priceId);

    /**
     * 取消提交
     * @param priceId 单价ID
     */
    int cancel(Long priceId);

    /**
     * 审核操作
     * @param dto 参数
     */
    int verify(PriceVerifyDTO dto);

    /**
     * 禁用操作
     * @param priceId 单价ID
     */
    int disable(Long priceId);

    /**
     * 启用操作
     * @param priceId 单价ID
     */
    int enable(Long priceId);

    /**
     * 导入单价列表
     *
     * @param priceList 单价列表
     * @param params
     * @param operaId   操作人ID
     */
    int importPrice(List<PriceVO> priceList, PriceImportParams params, Long operaId);

    /**
     * 根据ID列表查询
     * @param priceIds
     * @return
     */
    List<PriceVO> selectPriceListByIds(List<Long> priceIds);

    /**
     * 逻辑删除
     */
    int logicDel(Long id);

    /**
     * 查询条件
     */
    PriceSearchConditionVO selectSearchCondition(PriceQuery query);

    /**
     * 查询一个
     */
    PriceVO selectOne(PriceQuery query);
}
