package com.ruoyi.yh.price.service.impl;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.yh.material.utils.MaterialUtil;
import com.ruoyi.yh.price.domain.Price;
import com.ruoyi.yh.price.domain.dto.PriceVerifyDTO;
import com.ruoyi.yh.price.domain.dto.PriceVerifyPriceDTO;
import com.ruoyi.yh.price.domain.enums.PriceStatus;
import com.ruoyi.yh.price.service.PriceConverter;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author wjh
 * 2024/10/17
 */
@Service
public class PriceConverterImpl implements PriceConverter {

    /**
     * 创建时，转为PO
     */
    @Override
    public Price toPoByCreate(Price data) {
        if (data == null) {
            return null;
        }
        LoginUser loginUser = SecurityUtils.getLoginUser();

        Price po = new Price();
        po.setStatus(PriceStatus.WAIT_VERIFY.getStatus());
        po.setDisabled(false);
        po.setDeptId(data.getDeptId());
        po.setCategory(data.getCategory());
        po.setSize(data.getSize());
        po.setName(data.getName());
        po.setSubName(data.getSubName());
        po.setPattern(data.getPattern());
        po.setSpec(data.getSpec());
        po.setPrice(data.getPrice());
        po.setUnit(data.getUnit());
        po.setClassify(data.getClassify());
        po.setCreateId(loginUser.getUserId());
        po.setQuantityDenominator(data.getQuantityDenominator());
        po.setQuantityNumerator(data.getQuantityNumerator());
        po.setCreateBy(loginUser.getUsername());
        po.setRemark(data.getRemark());
        po.setSurface(data.getSurface());
        po.setCode(MaterialUtil.parseToCode(po.getCategory(), po.getSize(), po.getSurface(), po.getPattern()));
        return po;
    }

    @Override
    public Price toPoByUpdate(Price data) {
        if (data == null) {
            return null;
        }
        LoginUser loginUser = SecurityUtils.getLoginUser();

        Price po = new Price();
        po.setStatus(PriceStatus.WAIT_VERIFY.getStatus());
        po.setPriceId(data.getPriceId());
        po.setDeptId(data.getDeptId());
        po.setCategory(data.getCategory());
        po.setSize(data.getSize());
        po.setName(data.getName());
        po.setSubName(data.getSubName());
        po.setPattern(data.getPattern());
        po.setSpec(data.getSpec());
        po.setPrice(data.getPrice());
        po.setUnit(data.getUnit());
        po.setClassify(data.getClassify());
        po.setQuantityDenominator(data.getQuantityDenominator());
        po.setQuantityNumerator(data.getQuantityNumerator());
        po.setUpdateId(loginUser.getUserId());
        po.setUpdateBy(loginUser.getUsername());
        po.setRemark(data.getRemark());
        po.setCode(MaterialUtil.parseToCode(po.getCategory(), po.getSize(), po.getSurface(), po.getPattern()));
        return po;
    }

    @Override
    public List<Price> toPoByVerify(PriceVerifyDTO dto) {
        if (dto == null || CollectionUtils.isEmptyElement(dto.getPriceList())) {
            return Collections.emptyList();
        }

        SysUser verifyUser = dto.getVerifyUser();
        LocalDateTime verifyTime = LocalDateTime.now();
        String status = dto.getPass() ? PriceStatus.PASS.getStatus() : PriceStatus.REJECT.getStatus();

        List<Price> result = new ArrayList<>();
        for (PriceVerifyPriceDTO price : dto.getPriceList()) {
            Price data = new Price();
            data.setStatus(status);
            data.setVerifyTime(verifyTime);
            data.setPrice(price.getPrice());
            data.setPriceId(price.getPriceId());
            if (verifyUser != null) {
                data.setVerifyBy(verifyUser.getNickName());
                data.setVerifyId(verifyUser.getUserId());
            }
            result.add(data);
        }
        return result;
    }
}
