package com.ruoyi.yh.prodOrder.service;

import com.ruoyi.yh.prodOrder.domain.ProdOrder;
import com.ruoyi.yh.prodOrder.domain.ProdOrderQuery;
import com.ruoyi.yh.prodOrder.domain.ProdOrderVO;
import com.ruoyi.yh.prodOrder.domain.dto.ProdOrderSyncQuery;

import java.math.BigDecimal;
import java.util.List;

/**
 * 生产订单Service接口
 *
 * @author ruoyi
 * @date 2024-10-29
 */
public interface ProdOrderService
{
    /**
     * 查询生产订单
     *
     * @param id 生产订单主键
     * @return 生产订单
     */
    public ProdOrderVO selectProdOrderById(Long id);

    /**
     * 查询生产订单列表
     *
     * @param prodOrder 生产订单
     * @return 生产订单集合
     */
    public List<ProdOrderVO> selectProdOrderList(ProdOrderQuery prodOrder);

    /**
     * 新增生产订单
     *
     * @param prodOrder 生产订单
     * @return 结果
     */
    public int insertProdOrder(ProdOrder prodOrder);

    /**
     * 修改生产订单
     *
     * @param prodOrder 生产订单
     * @return 结果
     */
    public int updateProdOrder(ProdOrder prodOrder);

    /**
     * 批量删除生产订单
     *
     * @param ids 需要删除的生产订单主键集合
     * @return 结果
     */
    public int deleteProdOrderByIds(Long[] ids);

    /**
     * 删除生产订单信息
     *
     * @param id 生产订单主键
     * @return 结果
     */
    public int deleteProdOrderById(Long id);

    /**
     * 从ERP同步数据
     */
    void sync(ProdOrderSyncQuery query, Long operaId);

    /**
     * 根据单据编号查询单据
     */
    ProdOrderVO selectByBillNo(String billNo);

    /**
     * 查询单个
     * @param query
     * @return
     */
    ProdOrderVO selectOne(ProdOrderQuery query);

    /**
     * 增加已审核的基本单位数量
     * @param orderId 订单ID
     * @param num 增加数量
     */
    int addVerifiedBaseNum(Long orderId, BigDecimal num);

    /**
     * 查询简单列表
     *
     * @param query  查询条件
     * @param fields 字段列表
     */
    List<ProdOrderVO> selectSimpleList(ProdOrderQuery query, String ...fields);
}
