package com.ruoyi.yh.report.domain.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/10/31
 */
@Getter
@AllArgsConstructor
public enum ReportStatus {

    WAIT_SUBMIT("1", "待提交"),
    WAIT_VERIFY("2", "待审核"),
    PASS("3", "已通过"),
    REJECT("4", "未通过");

    private final String status;
    private final String msg;

    public static List<String> asList(ReportStatus ...statuses) {
        return Arrays.stream(statuses).map(ReportStatus::getStatus).collect(Collectors.toList());
    }

    /**
     * 允许审核的状态
     */
    public static List<String> canVerify() {
        return asList(WAIT_VERIFY);
    }

    /**
     * 允许取消审核的状态
     */
    public static List<String> canCancel() {
        return asList(WAIT_VERIFY);
    }

    /**
     * 允许提交的状态
     */
    public static List<String> canSubmit() {
        return asList(WAIT_SUBMIT);
    }

    /**
     * 允许修改的状态
     */
    public static List<String> canEdit() {
        return asList(WAIT_SUBMIT, REJECT);
    }

    /**
     * 允许重置审核员的状态
     */
    public static List<String> canResetVerify() {
        return asList(REJECT);
    }

    /**
     * 允许删除的状态
     */
    public static List<String> canDel() {
        return asList(WAIT_SUBMIT, REJECT);
    }
}
