package com.ruoyi.yh.report.mapper;

import com.ruoyi.dashboard.report.domain.sum.ReportSumVO;
import com.ruoyi.yh.report.domain.Report;
import com.ruoyi.yh.report.domain.ReportQuery;
import com.ruoyi.yh.report.domain.ReportVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 报表Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-18
 */
public interface ReportMapper
{
    /**
     * 查询报表
     *
     * @param reportId 报表主键
     * @return 报表
     */
    public ReportVO selectReportByReportId(Long reportId);

    /**
     * 查询报表列表
     *
     * @param query 报表
     * @return 报表集合
     */
    public List<ReportVO> selectReportList(@Param("query")ReportQuery query);

    /**
     * 新增报表
     *
     * @param report 报表
     * @return 结果
     */
    public int insertReport(Report report);

    /**
     * 修改报表
     *
     * @param report 报表
     * @return 结果
     */
    public int updateReport(@Param("data") Report report);

    /**
     * 删除报表
     *
     * @param reportId 报表主键
     * @return 结果
     */
    public int deleteReportByReportId(Long reportId);

    /**
     * 批量删除报表
     *
     * @param reportIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteReportByReportIds(Long[] reportIds);

    /**
     * 根据查询条件修改数据
     */
    int updateByQuery(@Param("data") Report data, @Param("query") ReportQuery query);

    /**
     * 重置审核信息
     */
    int resetVerifyInfoByQuery(@Param("query") ReportQuery query);

    /**
     * 逻辑删除
     */
    int logicDelByQuery(@Param("query") ReportQuery query);

    /**
     * 根据单价ID列表，计算报表总价
     * @param query 报表查询条件
     * @return 报表总价
     */
    int calcTotalAmount(@Param("query") ReportQuery query);

    /**
     * 查询报表统计
     * @param query 报表查询条件
     * @return 报表统计
     */
    ReportSumVO selectSum(@Param("query") ReportQuery query);
}
