package com.ruoyi.yh.reportOrderProd.service.impl;

import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.yh.reportOrderProd.domain.ReportOrderProd;
import com.ruoyi.yh.reportOrderProd.domain.ReportOrderProdQuery;
import com.ruoyi.yh.reportOrderProd.domain.ReportOrderProdVO;
import com.ruoyi.yh.reportOrderProd.domain.vo.ReportOrderProdSumOfBaseNumGroupByOrderIdVO;
import com.ruoyi.yh.reportOrderProd.mapper.ReportOrderProdMapper;
import com.ruoyi.yh.reportOrderProd.service.ReportOrderProdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 订单产量Service业务层处理
 *
 * @author ruoyi
 * @date 2024-11-19
 */
@Service
public class ReportOrderProdServiceImpl implements ReportOrderProdService
{
    @Autowired
    private ReportOrderProdMapper reportOrderProdMapper;

    /**
     * 查询订单产量
     *
     * @param id 订单产量主键
     * @return 订单产量
     */
    @Override
    public ReportOrderProdVO selectReportOrderProdById(Long id)
    {
        return reportOrderProdMapper.selectReportOrderProdById(id);
    }

    /**
     * 查询订单产量列表
     *
     * @param reportOrderProd 订单产量
     * @return 订单产量
     */
    @Override
    public List<ReportOrderProdVO> selectReportOrderProdList(ReportOrderProdQuery reportOrderProd)
    {
        return reportOrderProdMapper.selectReportOrderProdList(reportOrderProd);
    }

    /**
     * 新增订单产量
     *
     * @param reportOrderProd 订单产量
     * @return 结果
     */
    @Override
    public int insertReportOrderProd(ReportOrderProd reportOrderProd)
    {
        return reportOrderProdMapper.insertReportOrderProd(reportOrderProd);
    }

    /**
     * 修改订单产量
     *
     * @param reportOrderProd 订单产量
     * @return 结果
     */
    @Override
    public int updateReportOrderProd(ReportOrderProd reportOrderProd)
    {
        return reportOrderProdMapper.updateReportOrderProd(reportOrderProd);
    }

    /**
     * 批量删除订单产量
     *
     * @param ids 需要删除的订单产量主键
     * @return 结果
     */
    @Override
    public int deleteReportOrderProdByIds(Long[] ids)
    {
        return reportOrderProdMapper.deleteReportOrderProdByIds(ids);
    }

    /**
     * 删除订单产量信息
     *
     * @param id 订单产量主键
     * @return 结果
     */
    @Override
    public int deleteReportOrderProdById(Long id)
    {
        return reportOrderProdMapper.deleteReportOrderProdById(id);
    }

    @Override
    public List<ReportOrderProdVO> selectListByReportId(Long reportId) {
        if (reportId == null) {
            return null;
        }
        ReportOrderProdQuery query = new ReportOrderProdQuery();
        query.setReportId(reportId);
        return this.selectReportOrderProdList(query);
    }

    @Override
    public int batchInsert(List<? extends ReportOrderProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return reportOrderProdMapper.batchInsert(list);
    }

    @Override
    public int batchUpdate(List<? extends ReportOrderProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return reportOrderProdMapper.batchUpdate(list);
    }

    @Override
    public int batchLogicDel(List<? extends ReportOrderProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        List<Long> ids = CollectionUtils.map(list, ReportOrderProd::getId);
        return reportOrderProdMapper.batchLogicDel(ids);
    }

    @Override
    public List<ReportOrderProdSumOfBaseNumGroupByOrderIdVO> selectSumOfBaseNumGroupByOrderId(ReportOrderProdQuery query) {
        return reportOrderProdMapper.selectSumOfBaseNumGroupByOrderId(query);
    }

    @Override
    public int logicDelByReportId(Long reportId) {
        if (reportId == null) {
            return 0;
        }
        return reportOrderProdMapper.logicDelByReportId(reportId);
    }
}
