package com.ruoyi.yh.reportProd.mapper;

import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.dashboard.report.domain.sum.ReportProdSumVO;
import com.ruoyi.yh.reportProd.domain.ReportProd;
import com.ruoyi.yh.reportProd.domain.ReportProdQuery;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.domain.dto.ReportProdNewPriceDTO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 报表产量Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-31
 */
public interface ReportProdMapper
{
    /**
     * 查询报表产量
     *
     * @param id 报表产量主键
     * @return 报表产量
     */
    public ReportProdVO selectReportProdById(Long id);

    /**
     * 查询报表产量列表
     *
     * @param query 报表产量
     * @return 报表产量集合
     */
    public List<ReportProdVO> selectReportProdList(@Param("query")ReportProdQuery query);

    /**
     * 新增报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    public int insertReportProd(ReportProd reportProd);

    /**
     * 修改报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    public int updateReportProd(@Param("data") ReportProd reportProd);

    /**
     * 删除报表产量
     *
     * @param id 报表产量主键
     * @return 结果
     */
    public int deleteReportProdById(Long id);

    /**
     * 批量删除报表产量
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteReportProdByIds(Long[] ids);

    /**
     * 批量新增
     */
    int batchInsert(@Param("list") List<? extends ReportProd> productList);

    /**
     * 批量更新
     */
    int batchUpdate(@Param("list") List<? extends ReportProd> list);

    /**
     * 批量逻辑删除
     */
    int batchLogicDel(@Param("ids") List<Long> ids);

    /**
     * 批量根据报表id逻辑删除
     */
    int logicDelByReportId(Long reportId);

    /**
     * 批量更新单价
     */
    int batchUpdatePrice(@Param("list") List<ReportProdNewPriceDTO> list);

    /**
     * 刷新匹配的工序
     */
    int refreshPriceMatch(@Param("list") List<ReportProd> list);

    /**
     * 重置单价ID
     */
    int resetPriceId(@Param("ids") List<Long> ids);

    /**
     * 根据报表ID查询产量数量
     */
    List<LongIntegerVO> selectCountGroupByReportId(@Param("query") ReportProdQuery query);

    /**
     * 查询报表产量统计
     */
    ReportProdSumVO selectSum(@Param("query") ReportProdQuery query);
}
