package com.ruoyi.yh.reportProd.service.impl;

import com.ruoyi.common.utils.MathUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.yh.price.domain.PriceVO;
import com.ruoyi.yh.reportOrderProd.domain.ReportOrderProdVO;
import com.ruoyi.yh.reportOrderProd.domain.bo.ReportOrderProdBO;
import com.ruoyi.yh.reportOrderProd.service.ReportOrderProdConverter;
import com.ruoyi.yh.reportProd.domain.ReportProd;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.domain.bo.ReportProdBO;
import com.ruoyi.yh.reportProd.domain.dto.ReportProdNewPriceDTO;
import com.ruoyi.yh.reportProd.service.ReportProdConverter;
import com.ruoyi.yh.reportUserProd.domain.ReportUserProdVO;
import com.ruoyi.yh.reportUserProd.domain.bo.ReportUserProdBO;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author wjh
 * 2024/11/2
 */
@Service
public class ReportProdConverterImpl implements ReportProdConverter {

    @Autowired
    private ReportUserProdConverter reportUserProdConverter;

    @Autowired
    private ReportOrderProdConverter reportOrderProdConverter;

    @Override
    public ReportProdBO toBoByCreate(ReportProdVO vo, PriceVO price) {
        if (vo == null) {
            return null;
        }

        ReportProdBO bo = new ReportProdBO();
        bo.setNum(vo.getNum());
        bo.setPriceCategory(vo.getPriceCategory());
        bo.setPriceSize(vo.getPriceSize());
        bo.setPriceName(vo.getPriceName());
        bo.setPriceSubName(vo.getPriceSubName());
        bo.setPricePattern(vo.getPricePattern());
        bo.setPriceSpec(vo.getPriceSpec());
        bo.setPricePrice(vo.getPricePrice());
        bo.setPriceUnit(vo.getPriceUnit());
        bo.setPriceClassify(vo.getPriceClassify());
        bo.setPriceQuantityDenominator(vo.getPriceQuantityDenominator());
        bo.setPriceQuantityNumerator(vo.getPriceQuantityNumerator());
        bo.setPriceType(vo.getPriceType());
        bo.setRemark(vo.getRemark());
        bo.setDefectNum(vo.getDefectNum());
        bo.setPriceCode(vo.getPriceCode());
        bo.setSurface(vo.getSurface());
        bo.setColor(vo.getColor());
        bo.setIsEnd(vo.getIsEnd());
        bo.setSort(vo.getSort());
        this.setPriceInfo(bo, price);   // 设置单价信息（如果有）
        bo.setTotalAmount(this.calculateTotalAmount(bo));

        // 用户产量明细
        List<ReportUserProdBO> userProdList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getUserProdList())) {

            for (ReportUserProdVO item : vo.getUserProdList()) {
                ReportUserProdBO userProd = reportUserProdConverter.toBoByCreate(item);
                userProdList.add(userProd);
            }
        }
        bo.setUserProdList(userProdList);

        // 订单产量明细
        List<ReportOrderProdBO> orderProdList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getOrderProdList())) {
            for (ReportOrderProdVO item : vo.getOrderProdList()) {
                ReportOrderProdBO orderProd = reportOrderProdConverter.toBoByCreate(item);
                orderProdList.add(orderProd);
            }
        }
        bo.setOrderProdList(orderProdList);

        return bo;
    }

    @Override
    public ReportProdBO toBoByUpdate(ReportProdVO vo, PriceVO price) {
        if (vo == null) {
            return null;
        }

        ReportProdBO bo = new ReportProdBO();
        bo.setId(vo.getId());
        bo.setReportId(vo.getReportId());
        bo.setNum(vo.getNum());
        bo.setPriceCategory(vo.getPriceCategory());
        bo.setPriceSize(vo.getPriceSize());
        bo.setPriceName(vo.getPriceName());
        bo.setPriceSubName(vo.getPriceSubName());
        bo.setPricePattern(vo.getPricePattern());
        bo.setPriceSpec(vo.getPriceSpec());
        bo.setPricePrice(vo.getPricePrice());
        bo.setPriceUnit(vo.getPriceUnit());
        bo.setPriceClassify(vo.getPriceClassify());
        bo.setPriceQuantityDenominator(vo.getPriceQuantityDenominator());
        bo.setPriceQuantityNumerator(vo.getPriceQuantityNumerator());
        bo.setPriceType(vo.getPriceType());
        bo.setRemark(vo.getRemark());
        bo.setDefectNum(vo.getDefectNum());
        bo.setPriceCode(vo.getPriceCode());
        bo.setSurface(vo.getSurface());
        bo.setColor(vo.getColor());
        bo.setIsEnd(vo.getIsEnd());
        bo.setSort(vo.getSort());
        this.setPriceInfo(bo, price); // 设置单价信息（如果有）
        bo.setTotalAmount(this.calculateTotalAmount(bo));

        // 用户产量明细
        List<ReportUserProdBO> userProdList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getUserProdList())) {
            for (ReportUserProdVO item : vo.getUserProdList()) {
                ReportUserProdBO userProd = reportUserProdConverter.toBoByUpdate(item);
                userProdList.add(userProd);
            }
        }
        bo.setUserProdList(userProdList);

        // 订单产量明细
        List<ReportOrderProdBO> orderProdList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getOrderProdList())) {
            for (ReportOrderProdVO item : vo.getOrderProdList()) {
                ReportOrderProdBO orderProd = reportOrderProdConverter.toBoByUpdate(item);
                orderProdList.add(orderProd);
            }
        }
        bo.setOrderProdList(orderProdList);


        return bo;
    }

    @Override
    public void setPriceInfo(ReportProd prod, PriceVO price) {
        if (price != null) {
            prod.setPriceId(price.getPriceId());
            prod.setPriceCategory(price.getCategory());
            prod.setPriceSize(price.getSize());
            prod.setPriceName(price.getName());
            prod.setPriceSubName(price.getSubName());
            prod.setPricePattern(price.getPattern());
            prod.setPriceSpec(price.getSpec());
            prod.setPricePrice(price.getPrice());
            prod.setPriceUnit(price.getUnit());
            prod.setPriceClassify(price.getClassify());
            prod.setPriceQuantityDenominator(price.getQuantityDenominator());
            prod.setPriceQuantityNumerator(price.getQuantityNumerator());
        }
    }

    private BigDecimal calculateTotalAmount(ReportProdBO bo) {
        BigDecimal count = MathUtils.addDecimal(bo.getNum(), bo.getDefectNum());
        return MathUtils.multiply(bo.getPricePrice(), count);
    }

    @Override
    public List<ReportProdNewPriceDTO> toNewPriceDTO(List<PriceVO> passList) {
        if (CollectionUtils.isEmptyElement(passList)) {
            return Collections.emptyList();
        }

        List<ReportProdNewPriceDTO> result = new ArrayList<>();
        for (PriceVO price : passList) {
            ReportProdNewPriceDTO dto = new ReportProdNewPriceDTO();
            dto.setPriceId(price.getPriceId());
            dto.setPrice(price.getPrice());
            result.add(dto);
        }

        return result;
    }
}
