package com.ruoyi.yh.reportUserProd.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.yh.reportUserProd.domain.ReportUserProdQuery;
import com.ruoyi.yh.reportUserProd.domain.vo.ReportUserProdGroupByDateVO;
import com.ruoyi.yh.reportUserProd.domain.vo.ReportUserProdGroupByYearMonthVO;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdAssembler;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/11/2
 */
@Service
public class ReportUserProdAssemblerImpl implements ReportUserProdAssembler {

    @Autowired
    private ReportUserProdService reportUserProdService;

    @Override
    public void assembleChildren(List<ReportUserProdGroupByYearMonthVO> list, Long userId) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        // 确认日期范围
        // 获取列表最大年月、最小年月
        String pattern = "yyyy-MM";
        List<String> yearMonthList = list.stream().map(ReportUserProdGroupByYearMonthVO::getYearMonth).collect(Collectors.toList());
        LocalDate endDate = DateUtils.getMaxYearMonthLastDate(yearMonthList, pattern);
        LocalDate startDate = DateUtils.getMinYearMonthFirstDate(yearMonthList, pattern);

        // 查询列表
        ReportUserProdQuery query = new ReportUserProdQuery();
        query.setUserId(userId);
        query.setStartDate(startDate);
        query.setEndDate(endDate);
        List<ReportUserProdGroupByDateVO> groups = reportUserProdService.selectListGroupByDate(query);

        // 拼接数据
        for (ReportUserProdGroupByYearMonthVO vo : list) {
            List<ReportUserProdGroupByDateVO> children = groups.stream().filter(item ->
                    Objects.equals(item.getDate().getYear(), vo.getYear()) && Objects.equals(item.getDate().getMonthValue(), vo.getMonth())
            ).collect(Collectors.toList());
            vo.setChildren(children);
        }
    }
}
