package com.ruoyi.app;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.yh.reportUserProd.domain.ReportUserProdQuery;
import com.ruoyi.yh.reportUserProd.domain.ReportUserProdVO;
import com.ruoyi.yh.reportUserProd.domain.vo.ReportUserProdDetailVO;
import com.ruoyi.yh.reportUserProd.domain.vo.ReportUserProdGroupByDateVO;
import com.ruoyi.yh.reportUserProd.domain.vo.ReportUserProdGroupByYearMonthVO;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdAssembler;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdService;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDate;
import java.util.List;

/**
 * @author wjh
 * 2024/12/5
 */
@RestController
@RequestMapping("/app/userProd")
public class AppUserProdController extends BaseController {

    @Autowired
    private ReportUserProdService reportUserProdService;

    @Autowired
    private ReportUserProdAssembler reportUserProdAssembler;

    @ApiOperation("根据年月分组查询本人工资列表")
    @GetMapping("/listGroupByYearMonth")
    public TableDataInfo listGroupByYearMonth(ReportUserProdQuery query) {
        query.setUserId(getUserId());
        startPage();
        List<ReportUserProdGroupByYearMonthVO> list = reportUserProdService.selectListGroupByYearMonth(query);
        reportUserProdAssembler.assembleChildren(list, getUserId());
        return getDataTable(list);
    }

    @ApiOperation("根据日期分组查询本人工资列表")
    @GetMapping("/listGroupByDate")
    public TableDataInfo listGroupByDate(ReportUserProdQuery query) {
        query.setUserId(getUserId());
        startPage();
        return getDataTable(reportUserProdService.selectListGroupByDate(query));
    }

    @ApiModelProperty("按日查询本人工资明细")
    @GetMapping("/detailByDate")
    public AjaxResult detailByDate(@RequestParam @DateTimeFormat(pattern = "yyyy-MM-dd")LocalDate date) {
        ReportUserProdQuery query = new ReportUserProdQuery();
        query.setReportDate(date);
        query.setUserId(getUserId());
        List<ReportUserProdGroupByDateVO> groups = reportUserProdService.selectListGroupByDate(query);
        if (CollectionUtils.isEmptyElement(groups)) {
            return success();
        }
        List<ReportUserProdVO> list = reportUserProdService.selectReportUserProdList(query);

        ReportUserProdDetailVO vo = new ReportUserProdDetailVO();
        vo.setGroup(groups.get(0));
        vo.setList(list);
        return success(vo);
    }

}
