package com.ruoyi.web.yh;

import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.LogTitle;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.logImport.domain.LogImport;
import com.ruoyi.yh.logImport.domain.LogImportQuery;
import com.ruoyi.yh.logImport.domain.LogImportVO;
import com.ruoyi.yh.logImport.service.LogImportAssembler;
import com.ruoyi.yh.logImport.service.LogImportService;

/**
 * 导入日志Controller
 *
 * @author ruoyi
 * @date 2024-11-07
 */
@RestController
@RequestMapping("/yh/logImport")
public class LogImportController extends BaseController
{
    @Autowired
    private LogImportService logImportService;

    @Autowired
    private LogImportAssembler logImportAssembler;

    private static final String LOG_TITLE = LogTitle.LOG_IMPORT;

    /**
     * 查询导入日志列表
     */
    @PreAuthorize("@ss.hasPermi('yh:logImport:list')")
    @GetMapping("/list")
    public TableDataInfo list(LogImportQuery query)
    {
        startPage();
        startOrderBy();
        List<LogImportVO> list = logImportService.selectLogImportList(query);
        return getDataTable(list);
    }

    /**
     * 导出导入日志列表
     */
    @PreAuthorize("@ss.hasPermi('yh:logImport:export')")
    @Log(title = LOG_TITLE, businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LogImportQuery query)
    {
        startPage();
        List<LogImportVO> list = logImportService.selectLogImportList(query);
        ExcelUtil<LogImportVO> util = new ExcelUtil<LogImportVO>(LogImportVO.class);
        util.exportExcel(response, list, "导入日志数据");
    }

    /**
     * 获取导入日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:logImport:query')")
    @GetMapping(value = "/{logId}")
    public AjaxResult getInfo(@PathVariable("logId") Long logId)
    {
        LogImportVO detail = logImportService.selectLogImportByLogId(logId);
        return success(detail);
    }

    /**
     * 新增导入日志
     */
    @PreAuthorize("@ss.hasPermi('yh:logImport:add')")
    @Log(title = LOG_TITLE, businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LogImport logImport)
    {
        return toAjax(logImportService.insertLogImport(logImport));
    }

    /**
     * 修改导入日志
     */
    @PreAuthorize("@ss.hasPermi('yh:logImport:edit')")
    @Log(title = LOG_TITLE, businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LogImport logImport)
    {
        return toAjax(logImportService.updateLogImport(logImport));
    }

    /**
     * 删除导入日志
     */
    @PreAuthorize("@ss.hasPermi('yh:logImport:remove')")
    @Log(title = LOG_TITLE, businessType = BusinessType.DELETE)
	@DeleteMapping("/{logIds}")
    public AjaxResult remove(@PathVariable Long[] logIds)
    {
        return toAjax(logImportService.deleteLogImportByLogIds(logIds));
    }
}
