package com.ruoyi.web.yh;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.LogTitle;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LogBizType;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.service.PermissionService;
import com.ruoyi.yh.price.domain.Price;
import com.ruoyi.yh.price.domain.PriceQuery;
import com.ruoyi.yh.price.domain.PriceVO;
import com.ruoyi.yh.price.domain.dto.PriceImportParams;
import com.ruoyi.yh.price.domain.dto.PriceVerifyDTO;
import com.ruoyi.yh.price.service.PriceConverter;
import com.ruoyi.yh.price.service.PriceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.concurrent.ScheduledExecutorService;

/**
 * 单价Controller
 *
 * @author ruoyi
 * @date 2024-10-17
 */
@RestController
@RequestMapping("/yh/price")
public class PriceController extends BaseController
{
    @Autowired
    private PriceService priceService;

    @Autowired
    private PriceConverter priceConverter;

    @Autowired
    private ScheduledExecutorService scheduledExecutorService;

    @Autowired
    private PermissionService permissionService;

    @PreAuthorize("@ss.hasPermi('yh:price:list')")
    @GetMapping("/list")
    @DataScope(deptAlias = "sd")
    public TableDataInfo list(PriceQuery query)
    {
        startPage();
        startOrderBy();
        List<PriceVO> list = priceService.selectPriceList(query);
        return getDataTable(list);
    }

    /**
     * 获取查询条件数据
     */
    @PreAuthorize("@ss.hasPermi('yh:price:list')")
    @GetMapping("/searchCondition")
    @DataScope(deptAlias = "sd")
    public AjaxResult searchCondition(PriceQuery query)
    {
        return success(priceService.selectSearchCondition(query));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:list')")
    @PostMapping("/listByIds")
    public AjaxResult listByIds(@RequestBody List<Long> priceIds)
    {
        PriceQuery query = new PriceQuery();
        query.setPriceIds(priceIds);
        query.setNeedScope(true);
        List<PriceVO> list = priceService.selectPriceList(query);
        return success(list);
    }

    @PreAuthorize("@ss.hasPermi('yh:price:export')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.EXPORT, bizType = LogBizType.PRICE)
    @PostMapping("/export")
    @DataScope(deptAlias = "sd")
    public void export(HttpServletResponse response, PriceQuery query)
    {
        startPage();
        List<PriceVO> list = priceService.selectPriceList(query);
        ExcelUtil<PriceVO> util = new ExcelUtil<PriceVO>(PriceVO.class);
        util.exportExcel(response, list, "单价数据");
    }

    @PreAuthorize("@ss.hasPermi('yh:price:query')")
    @GetMapping(value = "/{priceId}")
    public AjaxResult getInfo(@PathVariable("priceId") Long priceId)
    {
        return success(priceService.selectPriceByPriceId(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:add')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.INSERT, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Price data)
    {
        Price po = priceConverter.toPoByCreate(data);
        return toAjax(priceService.insertPrice(po));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:edit')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.UPDATE, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Price data)
    {
        Price po = priceConverter.toPoByUpdate(data);
        return toAjax(priceService.updatePrice(po));
    }


    @PreAuthorize("@ss.hasPermi('yh:price:delete')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.DELETE, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @DeleteMapping("/{id}")
    public AjaxResult delete(@PathVariable Long id) {
        return toAjax(priceService.logicDel(id));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:submit')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.SUBMIT, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PutMapping("/{priceId}/submit")
    public AjaxResult submit(@PathVariable Long priceId) {
        return toAjax(priceService.submit(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:cancel')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.CANCEL, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PutMapping("/{priceId}/cancel")
    public AjaxResult cancel(@PathVariable Long priceId) {
        return toAjax(priceService.cancel(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:verify')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.VERIFY, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PutMapping("/verify")
    public AjaxResult verify(@RequestBody @Validated PriceVerifyDTO dto) {
        dto.setVerifyUser(SecurityUtils.getLoginUser().getUser());
        return success(priceService.verify(dto));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:disable')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.DISABLE, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PutMapping("/{priceId}/disable")
    public AjaxResult disable(@PathVariable Long priceId) {
        return toAjax(priceService.disable(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:enable')")
    @Log(title = LogTitle.PRICE, businessType = BusinessType.ENABLE, bizType = LogBizType.PRICE, bizIdName = "arg0")
    @PutMapping("/{priceId}/enable")
    public AjaxResult enable(@PathVariable Long priceId) {
        return toAjax(priceService.enable(priceId));
    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<PriceVO> util = new ExcelUtil<PriceVO>(PriceVO.class);
        util.importTemplateExcel(response, "单价数据");
    }

    @Log(title = "单价导入", businessType = BusinessType.IMPORT, bizType = LogBizType.PRICE)
    @PreAuthorize("@ss.hasPermi('yh:price:import')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, PriceImportParams params) throws Exception {
        if (params.getVerified() != null && params.getVerified() && !permissionService.hasPermi("yh:price:verify")) {
            return error("您无权直接审核通过");
        }
        ExcelUtil<PriceVO> util = new ExcelUtil<PriceVO>(PriceVO.class);
        List<PriceVO> priceList = util.importExcel(file.getInputStream());
        return success(priceService.importPrice(priceList, params, getUserId()));
    }
}
