package com.ruoyi.web.yh;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.reportProd.domain.ReportProd;
import com.ruoyi.yh.reportProd.domain.ReportProdQuery;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.service.ReportProdAssembler;
import com.ruoyi.yh.reportProd.service.ReportProdService;

/**
 * 报表产量Controller
 *
 * @author ruoyi
 * @date 2024-10-31
 */
@RestController
@RequestMapping("/yh/reportProd")
public class ReportProdController extends BaseController
{
    @Autowired
    private ReportProdService reportProdService;

    @Autowired
    private ReportProdAssembler reportProdAssembler;

    /**
     * 查询报表产量列表
     */
    @PreAuthorize("@ss.hasPermi('yh:reportProd:list')")
    @GetMapping("/list")
    public TableDataInfo list(ReportProdQuery query)
    {
        startPage();
        startOrderBy();
        List<ReportProdVO> list = reportProdService.selectReportProdList(query);
        reportProdAssembler.assembleUserProdList(list);
        reportProdAssembler.assembleOrderProdList(list);
        return getDataTable(list);
    }

    /**
     * 导出报表产量列表
     */
    @PreAuthorize("@ss.hasPermi('yh:reportProd:export')")
    @Log(title = "导出报表产量", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ReportProdQuery query)
    {
        startPage();
        List<ReportProdVO> list = reportProdService.selectReportProdList(query);
        ExcelUtil<ReportProdVO> util = new ExcelUtil<ReportProdVO>(ReportProdVO.class);
        util.exportExcel(response, list, "报表产量数据");
    }

    /**
     * 获取报表产量详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:reportProd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(reportProdService.selectReportProdById(id));
    }

    /**
     * 新增报表产量
     */
    @PreAuthorize("@ss.hasPermi('yh:reportProd:add')")
    @Log(title = "新增报表产量", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ReportProd reportProd)
    {
        return toAjax(reportProdService.insertReportProd(reportProd));
    }

    /**
     * 修改报表产量
     */
    @PreAuthorize("@ss.hasPermi('yh:reportProd:edit')")
    @Log(title = "修改报表产量", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ReportProd reportProd)
    {
        return toAjax(reportProdService.updateReportProd(reportProd));
    }

    /**
     * 删除报表产量
     */
    @PreAuthorize("@ss.hasPermi('yh:reportProd:remove')")
    @Log(title = "删除报表产量", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(reportProdService.deleteReportProdByIds(ids));
    }

    /**
     * 刷新单价匹配
     */
    @PutMapping("/priceMatch")
    @PreAuthorize("@ss.hasPermi('yh:reportProd:priceMatch')")
    @Log(title = "刷新单价匹配", businessType = BusinessType.UPDATE)
    public AjaxResult priceMatch(@RequestBody List<Long> ids){
        return success(reportProdService.refreshPriceMatch(ids));
    }
}
