package com.ruoyi.web.yh;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.reportUserProd.domain.ReportUserProdQuery;
import com.ruoyi.yh.reportUserProd.domain.ReportUserProdVO;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 员工产量Controller
 *
 * @author ruoyi
 * @date 2024-11-02
 */
@RestController
@RequestMapping("/yh/reportUserProd")
public class ReportUserProdController extends BaseController
{
    @Autowired
    private ReportUserProdService reportUserProdService;

    /**
     * 查询员工产量列表
     */
    @PreAuthorize("@ss.hasPermi('yh:reportUserProd:list')")
    @GetMapping("/list")
    @DataScope(deptAlias = "sd")
    public TableDataInfo list(ReportUserProdQuery query)
    {
        startPage();
        startOrderBy();
        List<ReportUserProdVO> list = reportUserProdService.selectReportUserProdList(query);
        return getDataTable(list);
    }

    /**
     * 导出员工产量列表
     */
    @PreAuthorize("@ss.hasPermi('yh:reportUserProd:export')")
    @Log(title = "导出员工产量", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ReportUserProdQuery query)
    {
        startPage();
        List<ReportUserProdVO> list = reportUserProdService.selectReportUserProdList(query);
        ExcelUtil<ReportUserProdVO> util = new ExcelUtil<ReportUserProdVO>(ReportUserProdVO.class);
        util.exportExcel(response, list, "员工产量数据");
    }

    /**
     * 获取员工产量详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:reportUserProd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(reportUserProdService.selectReportUserProdById(id));
    }

    /**
     * 新增员工产量
     */
//    @PreAuthorize("@ss.hasPermi('yh:reportUserProd:add')")
//    @Log(title = "新增员工产量", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody ReportUserProd reportUserProd)
//    {
//        return toAjax(reportUserProdService.insertReportUserProd(reportUserProd));
//    }
//
//    /**
//     * 修改员工产量
//     */
//    @PreAuthorize("@ss.hasPermi('yh:reportUserProd:edit')")
//    @Log(title = "修改员工产量", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody ReportUserProd reportUserProd)
//    {
//        return toAjax(reportUserProdService.updateReportUserProd(reportUserProd));
//    }
//
//    /**
//     * 删除员工产量
//     */
//    @PreAuthorize("@ss.hasPermi('yh:reportUserProd:remove')")
//    @Log(title = "删除员工产量", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{ids}")
//    public AjaxResult remove(@PathVariable Long[] ids)
//    {
//        return toAjax(reportUserProdService.deleteReportUserProdByIds(ids));
//    }
}
