package com.ruoyi.web.yh;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LogBizType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.shift.domain.Shift;
import com.ruoyi.yh.shift.domain.ShiftQuery;
import com.ruoyi.yh.shift.domain.ShiftVO;
import com.ruoyi.yh.shift.service.ShiftConverter;
import com.ruoyi.yh.shift.service.ShiftService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 调班Controller
 *
 * @author ruoyi
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/yh/shift")
public class ShiftController extends BaseController
{
    @Autowired
    private ShiftService shiftService;

    @Autowired
    private ShiftConverter shiftConverter;

    /**
     * 查询本部门创建的调班列表
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:list')")
    @GetMapping("/list")
    @DataScope(deptAlias = "sd")
    public TableDataInfo list(ShiftQuery query)
    {
        startPage();
        startOrderBy();
        List<ShiftVO> list = shiftService.selectShiftList(query);
        return getDataTable(list);
    }

    /**
     * 查询调到本部门的调班列表
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:list')")
    @GetMapping("/targetList")
    @DataScope(deptAlias = "sdt")
    public TableDataInfo targetList(ShiftQuery query) {
        startPage();
        startOrderBy();
        List<ShiftVO> list = shiftService.selectShiftList(query);
        return getDataTable(list);
    }

    /**
     * 导出调班列表
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:export')")
    @Log(title = "调班", businessType = BusinessType.EXPORT, bizType = LogBizType.SHIFT)
    @PostMapping("/export")
    @DataScope(deptAlias = "sd")
    public void export(HttpServletResponse response, ShiftQuery query)
    {
        startPage();
        List<ShiftVO> list = shiftService.selectShiftList(query);
        ExcelUtil<ShiftVO> util = new ExcelUtil<ShiftVO>(ShiftVO.class);
        util.exportExcel(response, list, "调班数据");
    }

    /**
     * 获取调班详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:query')")
    @GetMapping(value = "/{shiftId}")
    public AjaxResult getInfo(@PathVariable("shiftId") Long shiftId)
    {
        return success(shiftService.selectShiftByShiftId(shiftId));
    }

    /**
     * 新增调班
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:add')")
    @Log(title = "调班", businessType = BusinessType.INSERT, bizType = LogBizType.SHIFT, bizIdName = "arg0")
    @PostMapping
    public AjaxResult add(@RequestBody Shift shift)
    {
        SysUser user = getLoginUser().getUser();
        shift.setCreateId(user.getUserId());
        shift.setCreateBy(user.getNickName());
        shift.setDeptId(user.getDeptId());
        Shift po = shiftConverter.toPoByCreate(shift);
        return toAjax(shiftService.insertShift(po));
    }

    /**
     * 修改调班
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:edit')")
    @Log(title = "调班", businessType = BusinessType.UPDATE, bizType = LogBizType.SHIFT, bizIdName = "arg0")
    @PutMapping
    public AjaxResult edit(@RequestBody Shift shift)
    {
        SysUser user = getLoginUser().getUser();
        shift.setUpdateId(user.getUserId());
        shift.setUpdateBy(user.getNickName());
        Shift po = shiftConverter.toPoByUpdate(shift);
        return toAjax(shiftService.updateShift(po));
    }

    /**
     * 删除调班
     */
    @PreAuthorize("@ss.hasPermi('yh:shift:remove')")
    @Log(title = "调班", businessType = BusinessType.DELETE, bizType = LogBizType.SHIFT, bizIdName = "arg0")
	@DeleteMapping("/{shiftIds}")
    public AjaxResult remove(@PathVariable List<Long> shiftIds)
    {
        return toAjax(shiftService.logicDel(shiftIds));
    }
}
