package com.ruoyi.web.yh;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.LogTitle;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LogBizType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.unit.domain.Unit;
import com.ruoyi.yh.unit.domain.UnitQuery;
import com.ruoyi.yh.unit.domain.UnitVO;
import com.ruoyi.yh.unit.service.UnitService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 单位Controller
 *
 * @author ruoyi
 * @date 2024-11-18
 */
@RestController
@RequestMapping("/yh/unit")
public class UnitController extends BaseController
{
    @Autowired
    private UnitService unitService;

    private static final String LOG_TITLE = LogTitle.UNIT;

    /**
     * 查询单位列表
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:list')")
    @GetMapping("/list")
    public TableDataInfo list(UnitQuery query)
    {
        startPage();
        startOrderBy();
        List<UnitVO> list = unitService.selectUnitList(query);
        return getDataTable(list);
    }

    /**
     * 导出单位列表
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:export')")
    @Log(title = LOG_TITLE, businessType = BusinessType.EXPORT, bizType = LogBizType.UNIT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UnitQuery query)
    {
        startPage();
        List<UnitVO> list = unitService.selectUnitList(query);
        ExcelUtil<UnitVO> util = new ExcelUtil<UnitVO>(UnitVO.class);
        util.exportExcel(response, list, "单位数据");
    }

    /**
     * 获取单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:query')")
    @GetMapping(value = "/{unitId}")
    public AjaxResult getInfo(@PathVariable("unitId") Long unitId)
    {
        return success(unitService.selectUnitByUnitId(unitId));
    }

    /**
     * 新增单位
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:add')")
    @Log(title = LOG_TITLE, businessType = BusinessType.INSERT, bizType = LogBizType.UNIT, bizIdName = "arg0")
    @PostMapping
    public AjaxResult add(@RequestBody Unit unit)
    {
        return toAjax(unitService.insertUnit(unit));
    }

    /**
     * 修改单位
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:edit')")
    @Log(title = LOG_TITLE, businessType = BusinessType.UPDATE, bizType = LogBizType.UNIT, bizIdName = "arg0")
    @PutMapping
    public AjaxResult edit(@RequestBody Unit unit)
    {
        return toAjax(unitService.updateUnit(unit));
    }

    /**
     * 删除单位
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:remove')")
    @Log(title = LOG_TITLE, businessType = BusinessType.DELETE, bizType = LogBizType.UNIT, bizIdName = "arg0")
	@DeleteMapping("/{unitIds}")
    public AjaxResult remove(@PathVariable Long[] unitIds)
    {
        return toAjax(unitService.deleteUnitByUnitIds(unitIds));
    }

    /**
     * 同步单位
     */
    @PreAuthorize("@ss.hasPermi('yh:unit:sync')")
    @Log(title = LOG_TITLE, businessType = BusinessType.SYNC, bizType = LogBizType.UNIT)
	@PutMapping("/sync")
    public AjaxResult sync()
    {
        unitService.sync(getUserId());
        return success();
    }
}
